# swagger_client.HistoricalApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**categories_get**](HistoricalApi.md#categories_get) | **GET** /categories | Get historical stats for categories
[**category_get**](HistoricalApi.md#category_get) | **GET** /category | Get history for category ID
[**domain_get**](HistoricalApi.md#domain_get) | **GET** /domain | Get history for domain name
[**domains_get**](HistoricalApi.md#domains_get) | **GET** /domains | Get historical stats for domains
[**page_get**](HistoricalApi.md#page_get) | **GET** /page | Get page history for URL
[**pages_get**](HistoricalApi.md#pages_get) | **GET** /pages | Get historical stats for pages

# **categories_get**
> list[Categories] categories_get(country, subcountry=subcountry, from_date=from_date, to_date=to_date, keyword_filter=keyword_filter, lines=lines, offset=offset)

Get historical stats for categories

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint


# create an instance of the API class
api_instance = swagger_client.HistoricalApi(swagger_client.ApiClient(configuration))
country = 'country_example' # str | ISO_3166 country code in 2 letters
subcountry = 'subcountry_example' # str | state code (optional)
from_date = 'from_date_example' # str | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional)
to_date = 'to_date_example' # str | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional)
keyword_filter = 'keyword_filter_example' # str | Filter answers to cateogry names containing a particular keyword (optional)
lines = 50 # int | Get X results (max in one request is 10K please use offset paginated results if you need more) (optional) (default to 50)
offset = 0 # int | Get paginated results from X offset (optional) (default to 0)

try:
    # Get historical stats for categories
    api_response = api_instance.categories_get(country, subcountry=subcountry, from_date=from_date, to_date=to_date, keyword_filter=keyword_filter, lines=lines, offset=offset)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling HistoricalApi->categories_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **str**| ISO_3166 country code in 2 letters | 
 **subcountry** | **str**| state code | [optional] 
 **from_date** | **str**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **to_date** | **str**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **keyword_filter** | **str**| Filter answers to cateogry names containing a particular keyword | [optional] 
 **lines** | **int**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **int**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**list[Categories]**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **category_get**
> list[Category] category_get(id, country, subcountry=subcountry, from_date=from_date, to_date=to_date)

Get history for category ID

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint


# create an instance of the API class
api_instance = swagger_client.HistoricalApi(swagger_client.ApiClient(configuration))
id = 'id_example' # str | category id
country = 'country_example' # str | ISO_3166 country code in 2 letters
subcountry = 'subcountry_example' # str | state code (optional)
from_date = 'from_date_example' # str | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional)
to_date = 'to_date_example' # str | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional)

try:
    # Get history for category ID
    api_response = api_instance.category_get(id, country, subcountry=subcountry, from_date=from_date, to_date=to_date)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling HistoricalApi->category_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **str**| category id | 
 **country** | **str**| ISO_3166 country code in 2 letters | 
 **subcountry** | **str**| state code | [optional] 
 **from_date** | **str**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **to_date** | **str**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**list[Category]**](Category.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **domain_get**
> list[Domain] domain_get(domain, country, subcountry=subcountry, from_date=from_date, to_date=to_date)

Get history for domain name

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint


# create an instance of the API class
api_instance = swagger_client.HistoricalApi(swagger_client.ApiClient(configuration))
domain = 'domain_example' # str | domain name (no subdomain allowed)
country = 'country_example' # str | ISO_3166 country code in 2 letters
subcountry = 'subcountry_example' # str | state code (optional)
from_date = 'from_date_example' # str | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional)
to_date = 'to_date_example' # str | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional)

try:
    # Get history for domain name
    api_response = api_instance.domain_get(domain, country, subcountry=subcountry, from_date=from_date, to_date=to_date)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling HistoricalApi->domain_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **domain** | **str**| domain name (no subdomain allowed) | 
 **country** | **str**| ISO_3166 country code in 2 letters | 
 **subcountry** | **str**| state code | [optional] 
 **from_date** | **str**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **to_date** | **str**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**list[Domain]**](Domain.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **domains_get**
> list[Domains] domains_get(country, subcountry=subcountry, from_date=from_date, to_date=to_date, url_filter=url_filter, lines=lines, offset=offset)

Get historical stats for domains

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint


# create an instance of the API class
api_instance = swagger_client.HistoricalApi(swagger_client.ApiClient(configuration))
country = 'country_example' # str | ISO_3166 country code in 2 letters
subcountry = 'subcountry_example' # str | state code (optional)
from_date = 'from_date_example' # str | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional)
to_date = 'to_date_example' # str | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional)
url_filter = 'url_filter_example' # str | Filter answers to domains including a specified string (optional)
lines = 50 # int | Get X results (max in one request is 10K please use offset paginated results if you need more) (optional) (default to 50)
offset = 0 # int | Get paginated results from X offset (optional) (default to 0)

try:
    # Get historical stats for domains
    api_response = api_instance.domains_get(country, subcountry=subcountry, from_date=from_date, to_date=to_date, url_filter=url_filter, lines=lines, offset=offset)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling HistoricalApi->domains_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **str**| ISO_3166 country code in 2 letters | 
 **subcountry** | **str**| state code | [optional] 
 **from_date** | **str**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **to_date** | **str**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **url_filter** | **str**| Filter answers to domains including a specified string | [optional] 
 **lines** | **int**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **int**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**list[Domains]**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **page_get**
> list[Page] page_get(url, country, subcountry=subcountry, from_date=from_date, to_date=to_date)

Get page history for URL

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint


# create an instance of the API class
api_instance = swagger_client.HistoricalApi(swagger_client.ApiClient(configuration))
url = 'url_example' # str | Fully qualified page url. URL needs to be URL encoded
country = 'country_example' # str | ISO_3166 country code in 2 letters
subcountry = 'subcountry_example' # str | state code (optional)
from_date = 'from_date_example' # str | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional)
to_date = 'to_date_example' # str | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) (optional)

try:
    # Get page history for URL
    api_response = api_instance.page_get(url, country, subcountry=subcountry, from_date=from_date, to_date=to_date)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling HistoricalApi->page_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **url** | **str**| Fully qualified page url. URL needs to be URL encoded | 
 **country** | **str**| ISO_3166 country code in 2 letters | 
 **subcountry** | **str**| state code | [optional] 
 **from_date** | **str**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **to_date** | **str**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**list[Page]**](Page.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **pages_get**
> list[Pages] pages_get(preset_filter, from_date=from_date, to_date=to_date, country=country, subcountry=subcountry, domain_filter=domain_filter, url_filter=url_filter, category_filter=category_filter, keyword_filter=keyword_filter, lines=lines, offset=offset)

Get historical stats for pages

### Example
```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint


# create an instance of the API class
api_instance = swagger_client.HistoricalApi(swagger_client.ApiClient(configuration))
preset_filter = 56 # int | Apply preset filters => 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone
from_date = 'from_date_example' # str | Datas from YYYY-MM-DD (if not provided, last 30 days) (optional)
to_date = 'to_date_example' # str | Datas to YYYY-MM-DD (if not provided, last 30 days) (optional)
country = 'country_example' # str | ISO_3166 country code in 2 letters (if not provided  worldwide) (optional)
subcountry = 'subcountry_example' # str | state code (optional)
domain_filter = 'domain_filter_example' # str | Filter answers to pages of a designated domain name (optional)
url_filter = 'url_filter_example' # str | Filter answers to pages URL including a specified string (optional)
category_filter = 56 # int | Filter answers to a specific page category (optional)
keyword_filter = 'keyword_filter_example' # str | Filter answers to pages titles containing a particular keyword (optional)
lines = 50 # int | Get X results (max in one request is 50 please use offset paginated results if you need more) (optional) (default to 50)
offset = 0 # int | Get paginated results from X offset (optional) (default to 0)

try:
    # Get historical stats for pages
    api_response = api_instance.pages_get(preset_filter, from_date=from_date, to_date=to_date, country=country, subcountry=subcountry, domain_filter=domain_filter, url_filter=url_filter, category_filter=category_filter, keyword_filter=keyword_filter, lines=lines, offset=offset)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling HistoricalApi->pages_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **preset_filter** | **int**| Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone | 
 **from_date** | **str**| Datas from YYYY-MM-DD (if not provided, last 30 days) | [optional] 
 **to_date** | **str**| Datas to YYYY-MM-DD (if not provided, last 30 days) | [optional] 
 **country** | **str**| ISO_3166 country code in 2 letters (if not provided  worldwide) | [optional] 
 **subcountry** | **str**| state code | [optional] 
 **domain_filter** | **str**| Filter answers to pages of a designated domain name | [optional] 
 **url_filter** | **str**| Filter answers to pages URL including a specified string | [optional] 
 **category_filter** | **int**| Filter answers to a specific page category | [optional] 
 **keyword_filter** | **str**| Filter answers to pages titles containing a particular keyword | [optional] 
 **lines** | **int**| Get X results (max in one request is 50 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **int**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**list[Pages]**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

